import java.lang.*;

/*
-------------------------------------------------------------------------------
Competicio pels mateixos recursos (sense normalitzar)
-------------------------------------------------------------------------------
Dades: dt (mida del pas), imax (passos que es volen calcular), jmax 
       (iteracions per estabilitzar), nx0 (nombre inicial especie x),
       ny0 (nombre inicial especie y), a (influencia d'y sobre x), b
       (influencia de x sobre y), rx (taxa de creixement x), ry (taxa
       de creixement y), Kx (capacitat especie x), Ky (capacitat 
       especie y)
Resultats: Al fitxer "edos2.dat". Cada fila representa un instant de temps.
           La primera columna es el temps, la segona el nombre de membres de 
           l'especie x i la tercera el mateix pero de l'especie y.
Dades de prova: dt=0.05 imax=200 jmax=1 nx0=200 ny0=300 a=0.75 b=0.75
                rx=2.0 ry=2.0 Kx=1000 Ky=1000 ==>
                0.000000 200.000000 300.000000
                0.050000 211.500000 316.500000
                0.100000 223.156296 333.112305
                0.150000 234.916840 349.751953
                0.200000 246.727737 366.332306
                   ...      ...      ...
Observacions: Totes les quantitats es refereixen al model sense normalitzar.
              Nomes jmax=1 esta justificat teoricament.            
-------------------------------------------------------------------------------
*/

public class Edos2Calculs {
	double dt,nx0,ny0,a,b,rx,ry,Kx,Ky,temps[],trajx[],trajy[];
	int imax;

	Edos2Calculs(float dt0,int imax0,float nx00,float ny00,float a0,float b0,float rx0,float ry0,float Kx0,float Ky0) {
		double dx,dy,x0,y0,t0,x,y,t,xf,yf,tf,xm,ym,tm;
		int i,j,jmax;

		dt = (double) dt0;
		nx0 = (double) nx00;
		ny0 = (double) ny00;
		a = (double) a0;
		b = (double) b0;
		rx = (double) rx0;
		ry = (double) ry0;
		Kx = (double) Kx0;
		Ky = (double) Ky0;
		imax = imax0;
		jmax = 1;
		temps = new double[imax];
		trajx = new double[imax];
		trajy = new double[imax];

		t0=0;
		x=nx0;
		y=ny0;
		t=t0;
		xf=nx0;
		yf=ny0;
		temps[0]=t0;
		trajx[0]=nx0;
		trajy[0]=ny0;
		for(i=0;i<imax;i++) {
			tm=t+dt/2.0;
			for(j=0;j<jmax;j++) {
				xm=(x+xf)/2.0;
				ym=(y+yf)/2.0;
				dx=rx*(Kx-xm-a*ym)*xm*dt/Kx;
				dy=ry*(Ky-ym-b*xm)*ym*dt/Ky;
				xf=x+dx;
				yf=y+dy;
			}
			x=xf;
			y=yf;
			t=t+dt; 
			temps[i]=t;
			trajx[i]=x;
			trajy[i]=y;        
		}
	}
}
